@@ -12,11 +12,13 @@ config = Config({
     },
     "log": {
         "console_level": logbook.WARNING // Doc("console log level (can be repeated). Higher log level means quieter output.") // Cmdline(decrease="-v", increase="-q"),
+        "truncate_console_lines": True // Doc("truncate long log lines on the console") // Cmdline(arg='--truncate-console-lines', metavar='yes/no'),
         "root": None // Doc("Root directory for logs") // Cmdline(arg="-l", metavar="DIR"),
         "subpath": "{context.session.id}/{context.test_id}/log" // Doc("Path to write logs to under the root"),
         "session_subpath": "{context.session.id}/session.log",
-        "last_session_symlink": None // Doc("If set, saves a symlink to the last session log file in each run"),
-        "last_test_symlink": None // Doc("If set, saves a symlink to the last test log file in each run"),
+        "last_session_symlink": None // Doc("If set, specifies a symlink path to the last session log file in each run"),
+        "last_test_symlink": None // Doc("If set, specifies a symlink path to the last test log file in each run"),
+        "last_failed_symlink": None // Doc("If set, specifies a symlink path to the last failed test log file"),
         "silence_loggers": [] // Doc("Logger names to silence"),
         "format": None // Doc("Format of the log line, as passed on to logbook. None will use the default format"),
         "localtime": False // Doc("Use local time for logging. If False, will use UTC"),
@@ -25,6 +27,7 @@ config = Config({
         "default_sources": [] // Doc("Default tests to run assuming no other sources are given to the runner"),
         "suite_files": [] // Doc("File(s) to be read for lists of tests to be run") // Cmdline(append="-f", metavar="FILENAME"),
         "stop_on_error": False // Doc("Stop execution when a test doesn't succeed") // Cmdline(on="-x"),
+        "filter_string": None // Doc("A string filter, selecting specific tests by string matching against their name") // Cmdline(arg='-k', metavar='FILTER'),
         "session_state_path": "~/.slash/last_session" // Doc("Where to keep last session serialized data"),
         "user_customization_file_path": "~/.slash/slashrc",
     },
