@@ -1,5 +1,9 @@
+import gossip.exceptions
+import gossip.hooks
+from slash import hooks
+
 from .utils import TestCase
-from slash import hooks, exceptions
+
 
 class CustomHooksTest(TestCase):
 
@@ -14,7 +18,7 @@ class CustomHooksTest(TestCase):
         super(CustomHooksTest, self).tearDown()
 
     def test_hooks_are_globally_available_through_hooks_module(self):
-        self.assertIsInstance(hooks.some_custom_hook, hooks.Callback)
+        self.assertIsInstance(hooks.some_custom_hook, gossip.hooks.Hook)
         self.assertIs(hooks.some_custom_hook, self.hook)
 
     def test_ensure_custom_hook(self):
@@ -23,22 +27,14 @@ class CustomHooksTest(TestCase):
         self.addCleanup(hooks.remove_custom_hook, "new_custom_hook")
         self.assertIs(new_hook, hooks.new_custom_hook)
 
-    def test_ensure_custom_hook_does_not_allow_built_in_hooks(self):
-        with self.assertRaises(exceptions.HookAlreadyExists):
-            hooks.ensure_custom_hook("test_start")
-
     def test_hooks_appear_in_get_all_hooks(self):
         all_hooks = dict(hooks.get_all_hooks())
         self.assertIs(all_hooks[self.hook_name], self.hook)
 
-    def test_get_custom_hook_names(self):
-        self.assertEquals(hooks.get_custom_hook_names(), [self.hook_name])
-
     def test_cannot_reinstall_hook_twice(self):
-        with self.assertRaises(exceptions.HookAlreadyExists):
+        with self.assertRaises(gossip.exceptions.NameAlreadyUsed):
             hooks.add_custom_hook(self.hook_name)
 
     def test_cannot_install_default_hooks(self):
-        with self.assertRaises(exceptions.HookAlreadyExists):
+        with self.assertRaises(gossip.exceptions.NameAlreadyUsed):
             hooks.add_custom_hook("test_start")
-
